@@ -56,7 +56,7 @@ parse_int(stringstream &iparams, const string &param)
 /** Initialize an instance using the information in a URL.
     @param url The DAP URL with client-side parameters. */
 ClientParams::ClientParams(const string &url) throw(Error)
-    : d_url(url), d_preload(false), d_string_as_char_array(true), 
+    : d_url(url), d_preload(false), d_string_as_char_array(false),
     d_scoped_grid_dims(false), d_default_limit(0)
 {
     // Get the params off the front of the URL and replace []= with spaces.
