@@ -36,7 +36,7 @@
 
 #include "config_nc.h"
 
-static char rcsid[] not_used ={"$Id: Dattr.cc 15125 2006-11-21 23:12:00Z jimg $"};
+static char rcsid[] not_used ={"$Id: Dattr.cc 16751 2007-06-26 17:54:03Z jimg $"};
 
 #include "Dnetcdf.h"
 #include "Dncx.h"
@@ -334,9 +334,6 @@ int
 nc_inq_att(int cdfid, int varid, const char *name, 
 	   nc_type *datatypep, size_t *lenp)
 {
-#if 0
-    NCConnect &ncc = *((*conns)[cdfid]);
-#endif
     if (!conns || cdfid < 0 || cdfid > MAX_NC_OPEN 
 	|| (*conns)[cdfid] == NULL) // does the file id exist?
 	return NC_EBADID;
@@ -354,6 +351,7 @@ nc_inq_att(int cdfid, int varid, const char *name,
 
 	AttrTable::Attr_iter p;
 	AttrTable *dummy;
+	DBG(cerr << "In nc_inq_att: name: " << name << endl);
 	attr.find(name, &dummy, &p);
 
 	if (p == attr.attr_end())
@@ -362,7 +360,12 @@ nc_inq_att(int cdfid, int varid, const char *name,
 	if (datatypep == 0 && lenp == 0)
 	    return NC_NOERR;
 
+	if (p < attr.attr_begin() || p >= attr.attr_end())
+	    throw Error((string)"Bad iterator value when looking for " + name);
+
+	DBG(cerr << "Before attr.get_attr(p) ... ");
 	string attrV = attr.get_attr(p);
+	DBG(cerr << "After attr.get_attr(p)" << endl);
 	AttrType attrT = attr.get_attr_type(p);
 
 	if (lenp) 
@@ -401,6 +404,10 @@ nc_inq_att(int cdfid, int varid, const char *name,
         set_opendap_error(e);
 	return e.get_error_code();
     }
+    catch (exception &e) {
+	DBG(cerr << "nc_inq_att: Exception: " << e.what() << endl);
+	return NC_ENOTATT;
+    }
 
     return NC_NOERR ;
 }
@@ -408,9 +415,6 @@ nc_inq_att(int cdfid, int varid, const char *name,
 int 
 nc_inq_attlen(int cdfid, int varid, const char *name, size_t *lenp)
 {
-#if 0
-    NCConnect &ncc = *((*conns)[cdfid]);
-#endif
     if (!conns || cdfid < 0 || cdfid > MAX_NC_OPEN 
 	|| (*conns)[cdfid] == NULL) // does the file id exist?
 	return NC_EBADID;
@@ -448,6 +452,11 @@ nc_inq_attlen(int cdfid, int varid, const char *name, size_t *lenp)
         set_opendap_error(e);
 	return e.get_error_code();
     }
+    catch (exception &e) {
+	DBG(cerr << "nc_inq_attlen: Exception: " << e.what() << endl);
+	return NC_ENOTATT;
+    }
+
 
     return NC_NOERR;
 }
