@@ -36,12 +36,12 @@
 
 #include "config_nc.h"
 
-static char rcsid[] not_used ={"$Id: Dvar.cc 11906 2005-08-08 19:51:43Z root $"};
+static char rcsid[] not_used ={"$Id: Dvar.cc 16556 2007-05-23 21:13:45Z jimg $"};
 
 #include "Dnetcdf.h"
 #include "nc_util.h"
 
-#include "BaseType.h"
+#include <BaseType.h>
 
 /** Defined in lnetcdf/lerror. This is not included in a header (like
     lnetcdf.h because doing so would require all sources that use lnetcdf.h
