@@ -12,12 +12,12 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -31,7 +31,7 @@
 //      reza            Reza Nekovei (rnekovei@ieee.org)
 
 // netCDF sub-class implementation for NCByte,...NCGrid.
-// The files are patterned after the subcalssing examples 
+// The files are patterned after the subcalssing examples
 // Test<type>.c,h files.
 //
 // ReZa 1/12/95
@@ -39,7 +39,8 @@
 #include "config_nc.h"
 
 static char rcsid[] not_used =
-    { "$Id: NCArray.cc 13725 2006-04-19 18:06:01Z jimg $" };
+    { "$Id: NCArray.cc 16556 2007-05-23 21:13:45Z jimg $"
+    };
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -71,14 +72,13 @@ BaseType *NCArray::ptr_duplicate()
 
 /** Build an NCArray instance.
     @param n The name of the array.
-    @param v Use this variable as a template for type of array elements. 
+    @param v Use this variable as a template for type of array elements.
     The variable will be copied, so the caller is responsible for freeing
     storage used by the actual parameter. Also, if the actual parameter
     is an Array, libdap++ code will use the template of that Array as the
     template for this NCArray. */
-NCArray::NCArray(const string & n, BaseType * v):Array(n, v)
-{
-}
+NCArray::NCArray(const string & n, BaseType * v): Array(n, v)
+{}
 
 NCArray::NCArray(const NCArray & rhs): Array(rhs), NCAccess(rhs)
 {
@@ -93,10 +93,10 @@ NCArray::~NCArray()
 }
 
 void
- NCArray::m_duplicate(const NCArray & nca)
+NCArray::m_duplicate(const NCArray & nca)
 {
     dynamic_cast < NCAccess & >(*this).clone(dynamic_cast <
-                                             const NCAccess & >(nca));
+            const NCAccess & >(nca));
 }
 
 NCArray & NCArray::operator=(const NCArray & rhs)
@@ -178,9 +178,9 @@ void NCArray::store_projection(const string & proj)
 }
 
 string
-    NCArray::build_constraint(int outtype, const size_t * start,
-                              const size_t * edges,
-                              const ptrdiff_t * stride) throw(Error)
+NCArray::build_constraint(int outtype, const size_t * start,
+                          const size_t * edges,
+                          const ptrdiff_t * stride) throw(Error)
 {
     // Test for bad conversion here, before we may call NCSequence (which
     // cannot run the test).
@@ -193,7 +193,7 @@ string
 
     // Get dimension sizes and strings for constraint hyperslab
     ostringstream ce;           // Build CE here.
-    int dm = 0;                 // Index to start, edge, stride arrays 
+    int dm = 0;                 // Index to start, edge, stride arrays
     int Zedge = 0;              // Search for zero size edges (no data)
 
     // If we found an array...
@@ -205,9 +205,9 @@ string
             throw Error(NC_ESTRIDE, "Stride less than 1 (one).");
 
         // Set defaults:
-        // *start         NULL => first corner 
-        // *edges         NULL => everything following start[] 
-        // *stride        NULL => unity strides 
+        // *start         NULL => first corner
+        // *edges         NULL => everything following start[]
+        // *stride        NULL => unity strides
         long instart = start != NULL ? start[dm] : 0;
         long inedges =
             edges != NULL ? edges[dm] : dimension_size(d) - instart;
@@ -221,7 +221,8 @@ string
             ext_step = (*cl_iter).stride;
             ext_stop = (*cl_iter).stop;
             ++cl_iter;
-        } else {
+        }
+        else {
             ext_start = 0;
             ext_step = 1;
             ext_stop = dimension_size(d) - 1;
@@ -285,7 +286,7 @@ bool NCArray::is_convertable(int outtype)
     (the thing actually sent by the server) is an Array so asking for N
     elements must always return N elements. See NCAccess::extract_values()
     and NCStr::extract_values() for cases where this is not always true.
-    
+
     @param values Destination buffer
     @param elements Expect this number of elements (i.e., what values can hold)
     @param outtype The netCDF type the client expects to see. */
@@ -301,9 +302,9 @@ void NCArray::extract_values(void *values, int /*elements*/, int outtype,
     case dods_int32_c:
     case dods_uint32_c:
     case dods_float32_c:
-    case dods_float64_c:{
+    case dods_float64_c: {
             char *tmpbufin = 0;
-            int bytes = buf2val((void **) &tmpbufin);
+            int bytes = buf2val((void **) & tmpbufin);
             if (bytes == 0)
                 throw Error(-1,
                             "Could not read any data from remote server.");
@@ -323,7 +324,7 @@ void NCArray::extract_values(void *values, int /*elements*/, int outtype,
         }                       // End of the case where the array template type is a byte, ..., float64
 
     case dods_str_c:
-    case dods_url_c:{
+    case dods_url_c: {
             // rcode = NC_NOERR;
             char *tbfr = (char *) values;
             string *sa = new string[nels];
@@ -463,8 +464,9 @@ bool NCArray::read(const string & dataset)
         // clean up
         delete[]flt32;
         delete[]fltbuf;
-    } else if ((datatype == NC_DOUBLE)
-               && (nctypelen(datatype) != sizeof(dods_float64))) {
+    }
+    else if ((datatype == NC_DOUBLE)
+             && (nctypelen(datatype) != sizeof(dods_float64))) {
 
         dblbuf = (double *) new char[(nels * nctypelen(datatype))];
 
@@ -490,8 +492,9 @@ bool NCArray::read(const string & dataset)
         // clean up
         delete[]flt64;
         delete[]dblbuf;
-    } else if ((datatype == NC_SHORT)
-               && (nctypelen(datatype) != sizeof(dods_int16))) {
+    }
+    else if ((datatype == NC_SHORT)
+             && (nctypelen(datatype) != sizeof(dods_int16))) {
 
         shtbuf = (short *) new char[(nels * nctypelen(datatype))];
 
@@ -517,8 +520,9 @@ bool NCArray::read(const string & dataset)
         // clean up
         delete[]intg16;
         delete[]shtbuf;
-    } else if ((datatype == NC_LONG)
-               && (nctypelen(datatype) != sizeof(dods_int32))) {
+    }
+    else if ((datatype == NC_LONG)
+             && (nctypelen(datatype) != sizeof(dods_int32))) {
 
         lngbuf = (nclong *) new char[(nels * nctypelen(datatype))];
 
@@ -543,7 +547,8 @@ bool NCArray::read(const string & dataset)
         // clean up
         delete[]intg32;
         delete[]lngbuf;
-    } else if (datatype == NC_CHAR) {
+    }
+    else if (datatype == NC_CHAR) {
 
         chrbuf = (char *) new char[(nels * nctypelen(datatype))];
 
@@ -576,7 +581,8 @@ bool NCArray::read(const string & dataset)
         // clean up
         delete[]strg;
         delete[]chrbuf;
-    } else {
+    }
+    else {
         //default (no type conversion needed and the type Byte)
         char *convbuf = new char[(nels * nctypelen(datatype))];
 
@@ -621,17 +627,17 @@ void NCArray::set_source(BaseType * s) throw(InternalErr)
     DBG(cerr << "s " << s << ", d_source " << d_source << endl);
 }
 
-/** Arrays are really constructor types. To flateen one, flatten the 
+/** Arrays are really constructor types. To flateen one, flatten the
     template variable and then append the array's dimensions to each of
     the variable returned as a result.
-    
+
     @note Four cases: 1. top level array, 2. top level array of structs,
     3. array inside a struct, 4. struct array inside a struct.
-    
+
     @todo Optimize by not doing all that if the contained variable is
     an atomic type. */
 VarList
-    NCArray::flatten(const ClientParams & cp, const string & parent_name)
+NCArray::flatten(const ClientParams & cp, const string & parent_name)
 {
 #if 0
     BaseType *btp = var();
@@ -641,7 +647,7 @@ VarList
     VarList template_vars =
         dynamic_cast < NCAccess * >(var())->flatten(cp, parent_name);
 #endif
-    // At this point we can delete the original template variable (which 
+    // At this point we can delete the original template variable (which
     // might be a Structure or Sequence, so there may be several variables
     // in place of the single template). Deleting the template keeps from
     // copying it repeatedly in the while-loop.
