@@ -34,10 +34,12 @@
 //
 // jhrg 9/29/94
 
+//#define DODS_DEBUG
+
 #include "config_nc.h"
 
 static char rcsid[] not_used =
-    { "$Id: NCConnect.cc 15125 2006-11-21 23:12:00Z jimg $" };
+    { "$Id: NCConnect.cc 16751 2007-06-26 17:54:03Z jimg $" };
 
 #include "netcdf.h"
 
@@ -107,9 +109,9 @@ static nc_type get_attr_nc_type(AttrType attrT) throw(Error)
     
     @param name A filename or URL. */
 NCConnect::NCConnect(const string & name, ClientParams * cp)
-:AISConnect(name), d_client_params(cp), d_global_attributes(0),
-d_constrained_dds(0), d_translated_dds(0), d_factory(0),
-d_ncid(-1), d_nvars(-1), d_recdim(-1), d_ndims(0)
+    :AISConnect(name), d_client_params(cp), d_global_attributes(0),
+    d_constrained_dds(0), d_translated_dds(0), d_factory(0),
+    d_ncid(-1), d_nvars(-1), d_recdim(-1), d_ndims(0)
       // Note the trick above where d_factory is initialized to null and null
       // is passed to the two DDS objects. This prevents this ctor from trying
       // to call the default ctor for DDS (which doesn't exist). In the body 
@@ -176,7 +178,7 @@ void NCConnect::init_remote_source(const string & ce) throw(Error)
 
     // Search for global attributes. For netCDF, the global attributes must
     // all be atomic; no containers within the global attr container. These
-    // two lines of code transfer the global attributes from the constrained
+    // lines of code transfer the global attributes from the constrained
     // DDS to the AttrTable held by this object and then flatten those
     // attributes. 
     set_global_attributes();
@@ -198,7 +200,6 @@ void NCConnect::init_remote_source(const string & ce) throw(Error)
         flatten_attributes(at);
     }
 
-
     // Build info about dimensions.    
     d_ndims = 0;
     parse_grid_dims(d_translated_dds);
@@ -391,6 +392,13 @@ char *NCConnect::get_raw_values(int varid, const char *name,
         values = 0;
         throw e;
     }
+    catch (exception &e) {
+	DBG(cerr << "NCConnect::get_raw_values: Exception: " << e.what()
+                 << endl);
+        delete[]values;
+        values = 0;
+	throw Error(e.what());
+    }
 
     return values;
 }
@@ -529,9 +537,9 @@ const char *likely_global_attrs[] =
     container and merge them. It could also read the names of likely 
     containers from the .dodsrc file.
 
-    @note This method uses the 'donstrained DDS' not the 'translated DDS'
+    @note This method uses the 'constrained DDS' not the 'translated DDS'
     because it assumes that a previous call has transferred the attributes
-    from a DAS into the constrained DDS (which is the DDS straing from the 
+    from a DAS into the constrained DDS (which is the DDS straight from the 
     server, with no translation applied). If we tried to merge the DAS info
     from the server with the translated DDS there's little chance it would
     work since the variable names are likely to be different in a translated
@@ -596,7 +604,6 @@ void NCConnect::flatten_attributes(AttrTable & at)
 
     delete el;
     el = 0;
-
 }
 
 
@@ -651,9 +658,12 @@ void NCConnect::translate_dds()
         delete *i;
         *i++ = 0;
     }
-
+    DBG(cerr << "d_constrained_dds.get_dataset_name(): "
+             << d_constrained_dds.get_dataset_name() << endl); 
     d_translated_dds.set_dataset_name(d_constrained_dds.
                                       get_dataset_name());
+    DBG(cerr << "d_translated_dds.get_dataset_name(): "
+             << d_translated_dds.get_dataset_name() << endl); 
 }
 
 // Adds dimensions to the look up table for Grid class 
@@ -768,7 +778,6 @@ void NCConnect::parse_string_dims(DDS & dds)
             get_dods_str_dim(*s, dimname, dimsize);
 
             // add new dimension if not already there
-            // Change altname actual to "". jhrg 8/22/06
             add_dim_if_new(dimname, dimsize, dimname + "-chars");
         }
 
@@ -776,10 +785,8 @@ void NCConnect::parse_string_dims(DDS & dds)
     }
 }
 
-void NCConnect::get_dods_str_dim(BaseType * s, string & dimname,
-                                 int &dimsize)
+void NCConnect::get_dods_str_dim(BaseType * s, string & dimname, int &dimsize)
 {
-
     AttrTable & attr = s->get_attr_table();
     AttrTable::Attr_iter pl;
     AttrTable::Attr_iter pd;
@@ -789,8 +796,7 @@ void NCConnect::get_dods_str_dim(BaseType * s, string & dimname,
     attr.find("DODS:strlen", &dummy, &pl);
     attr.find("DODS:dimName", &dummy, &pd);
 
-    // if not found, try longer version that results from
-    // converting structures
+    // if not found, try longer version that results from flattening containers
     if ((pl == attr.attr_end()) && (pd == attr.attr_end())) {
         string deepname = s->name();
         size_t l = deepname.find_last_of('.');
@@ -800,16 +806,15 @@ void NCConnect::get_dods_str_dim(BaseType * s, string & dimname,
             attr.find(deepname + ":" + "DODS.dimName", &dummy, &pd);
         }
     }
+    
     // were they found?
     if ((pl != attr.attr_end()) && (pd != attr.attr_end())) {
-
         // extract the dim name and size from them
         dimsize = atoi(attr.get_attr(pl, 0).c_str());
         dimname = attr.get_attr(pd, 0);
 
     }
-    // else, use a fixed size
-    else {
+    else { // else, use a fixed size
         dimname = s->name() + "-chars";
         dimsize = STRING_ARRAY_SIZE;
     }
