@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: lncio.h 11906 2005-08-08 19:51:43Z root $ */
+/* $Id: lncio.h 14988 2006-11-01 22:21:09Z jimg $ */
 
 #ifndef _NCIO_H_
 #define _NCIO_H_
@@ -37,7 +37,7 @@ typedef struct ncio ncio;	/* forward reference */
  * The next four typedefs define the signatures
  * of function pointers in struct ncio below.
  * They are not used outside of this file and lncio.h,
- * They just some casts in the ncio.c more readable.
+ * They just make some casts in the ncio.c more readable.
  */
 	/*
 	 * Indicate that you are done with the region which begins
@@ -112,7 +112,7 @@ struct ncio {
 
 	/*
 	 * A copy of the 'path' argument passed in to ncio_open()
-	 * or ncio_create(). Used by lncabort() to remove (unlink)
+	 * or ncio_create(). Used by ncabort() to remove (unlink)
 	 * the file and by error messages.
 	 */
 	const char *path;
@@ -138,4 +138,10 @@ ncio_open(const char *path,
 extern int 
 ncio_close(ncio *nciop, int doUnlink);
 
+extern int
+ncio_filesize(ncio *nciop, off_t *filesizep);
+
+extern int
+ncio_pad_length(ncio *nciop, off_t length);
+
 #endif /* _NCIO_H_ */
