@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: lvar.c 11906 2005-08-08 19:51:43Z root $ */
+/* $Id: lvar.c 14988 2006-11-01 22:21:09Z jimg $ */
 
 #include "lnc.h"
 #include <stdlib.h>
@@ -403,7 +403,13 @@ NC_var_shape(NC_var *varp, const NC_dimarray *dims)
 
 
 out :
-	varp->len = product * varp->xsz;
+    if( varp->xsz <= X_UINT_MAX / product ) /* if integer multiply will not overflow */
+	{
+	        varp->len = product * varp->xsz;
+        } else
+	{	/* OK for last var to be "too big", indicated by this special len */
+	        varp->len = X_UINT_MAX;
+        }
 	switch(varp->type) {
 	case NC_BYTE :
 	case NC_CHAR :
@@ -425,6 +431,28 @@ out :
 	return NC_NOERR;
 }
 
+/*
+ * Check whether variable size is less than or equal to vlen_max,
+ * without overflowing in arithmetic calculations.  If OK, return 1,
+ * else, return 0.  For CDF1 format or for CDF2 format on non-LFS
+ * platforms, vlen_max should be 2^31 - 4, but for CDF2 format on
+ * systems with LFS it should be 2^32 - 4.
+ */
+int
+NC_check_vlen(NC_var *varp, size_t vlen_max) {
+    size_t prod=varp->xsz;	/* product of xsz and dimensions so far */
+
+    int ii;
+
+    for(ii = IS_RECVAR(varp) ? 1 : 0; ii < varp->ndims; ii++) {
+	if (varp->shape[ii] > vlen_max / prod) {
+	    return 0;		/* size in bytes won't fit in a 32-bit int */
+	}
+	prod *= varp->shape[ii];
+    }
+    return 1;			/* OK */
+}
+
 
 /*
  * Given valid ncp and varid, return var
