@@ -32,10 +32,11 @@
 
 // Utility functions used by the netCDF CL code.
 
+// #define DODS_DEBUG
 #include "config_nc.h"
 
 static char rcsid[] not_used =
-    { "$Id: nc_util.cc 15135 2006-11-22 21:05:57Z jimg $" };
+    { "$Id: nc_util.cc 16751 2007-06-26 17:54:03Z jimg $" };
 
 #include <sstream>
 
@@ -88,7 +89,8 @@ BaseType *find_ancestral_sequence(BaseType * child)
     @param attr Read the attribute from this table.
     @param p The Attr_iter which references the attribute.
     @param values The buffer; a value-result parameter
-    @return The number of bytes read.
+    @return The number of values read. Allocate this return * nctypelen()
+    bytes to hold the value(s).
     @exception InternalErr Thrown if the type of the attribute is not
     supported. */
 int
@@ -161,27 +163,24 @@ throw(InternalErr)
             for (i = 0; i < attr_siz; i++) {
                 string value = attr.get_attr(p, i);
 
-                // remove quotes
-                if ((value[0] == '"')
-                    && (value[value.length() - 1] == '"')) {
-                    value = value.substr(1, value.length() - 2);
-                }
-
-                DBG(cerr << "XXX" << value << "XXX" << endl);
+		// Remove escape characters
                 value = unescattr(value);
-                DBG(cerr << "XXX" << value << "XXX" << endl);
+
+                // remove quotes
+                if ((value[0] == '"') && (value[value.length() - 1] == '"'))
+                    value = value.substr(1, value.length() - 2);
 
                 memcpy(cp + offset, value.c_str(), value.length());
                 offset += value.length();
-                DBG(cerr << "offset: " << offset << endl);
-                if (attr_siz > 1) {
-                    // Separate strings by EOL
+
+                if (attr_siz > 1) { // Separate strings by EOL
+
                     *(cp + offset) = '\n';
                     offset++;
                 }
             }
 
-            // End the string attribute by EOS, if array of string was sent
+	    // Replace the last \n with \0 
             if (attr_siz > 1)
                 *(cp + offset - 1) = '\0';
 
@@ -721,6 +720,12 @@ GenRead(int cdfid, int varid, const size_t * start, const size_t * count,
     }                           // IMAP loop 
 }
 
+/** Count the size of the string/char attribute and return the number of
+    bytes needed to store the value(s). 
+
+    @param attr Read values from this attribute table.
+    @param p Use this iterator to select a particular attribute.
+    @return The number of bytes to allocate for the value(s). */
 int compute_string_attr_length(AttrTable & attr, AttrTable::Attr_iter & p)
 {
     int len = 0;
@@ -728,27 +733,24 @@ int compute_string_attr_length(AttrTable & attr, AttrTable::Attr_iter & p)
     // string length is the total number of bytes plus the
     // terminating character. There is a '\n' at the end of each
     // string, but a '\0' at the end of the attibutes.
-    unsigned int attr_siz = attr.get_attr_num(p);
+    unsigned int attr_num = attr.get_attr_num(p);
 
-    for (unsigned int i = 0; i < attr_siz; i++) {
-        string attrV = attr.get_attr(p, i);
+    for (unsigned int i = 0; i < attr_num; i++) {
+        string value = attr.get_attr(p, i);
 
         // Compute length using the unescaped attribute since that's the
         // value the netcdf interface will return to the user's program. See
         // ticket 665. jhrg 11/21/06
+        value = unescattr(value);
 
-        attrV = unescattr(attrV);
+        len += value.length();
 
-        len += attrV.length();  // EOS included, quotes removed  
+        if ((value[0] == '"') && (value[value.length() - 1] == '"'))
+            len -= 2;		// Later code will remove the quotes
 
-        if ((attrV[0] == '"') && (attrV[attrV.length() - 1] == '"')) {
-            len -= 1;           // EOS included, quotes removed  
-
-            // single string (coming from a netCDF server) remove EOS
-            // for compatibility
-            if ((i == 0) && (attr.get_attr_num(p) == 1))
-                len -= 1;
-        }
+	if (attr_num > 1)
+	    len++;		// Add space for \n separator
     }
+    
     return len;
 }
