@@ -38,7 +38,7 @@
 #define Tfloat 7
 #define Tdouble 8
 
-#define STRING_AS_ARRAY 1
+#undef STRING_AS_ARRAY
 #define STRING_ARRAY_SIZE 128
 
 typedef list<BaseType*> VarList;
@@ -49,9 +49,11 @@ typedef list<AttrTable::entry> EntryList;
 
 // Utility functions used by the netCDF CL code.
 
+string unescape_string_attribute(const string &attr);
 int copy_attributes(AttrTable &attr, AttrTable::Attr_iter &p, void *values) 
     throw(InternalErr);
 EntryList *transfer_attributes_to_list(AttrTable *, const string &name = "");
+void attributes_list_to_table(AttrTable &at,EntryList *el);
 AttrTable *attributes_list_to_table(EntryList *el);
 void var_info(int cdfid, BaseType *bt, nc_type *typep, int *ndimsp, int dims[]) 
     throw(InternalErr);
@@ -65,6 +67,7 @@ int DODvario(int cdfid, int varid, const size_t *start, const size_t *edges,
 int GenRead(int cdfid, int varid, const size_t *start, const size_t *count,
     const ptrdiff_t *stride, const ptrdiff_t *imap, void *values, 
     int outtype);
+int compute_string_attr_length(AttrTable &attr, AttrTable::Attr_iter &p);
     
 
 // $Log: nc_util.h,v $
